<?php

namespace Ebuy\Product\Policies;

use Litepie\User\Contracts\UserPolicy;
use Ebuy\Product\Models\ProductGroup;

class ProductGroupPolicy
{

    /**
     * Determine if the given user can view the product_group.
     *
     * @param UserPolicy $user
     * @param ProductGroup $product_group
     *
     * @return bool
     */
    public function view(UserPolicy $user, ProductGroup $product_group)
    {
        if ($user->canDo('product.product_group.view') && $user->isAdmin()) {
            return true;
        }

        return $product_group->user_id == user_id() && $product_group->user_type == user_type();
    }

    /**
     * Determine if the given user can create a product_group.
     *
     * @param UserPolicy $user
     * @param ProductGroup $product_group
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('product.product_group.create');
    }

    /**
     * Determine if the given user can update the given product_group.
     *
     * @param UserPolicy $user
     * @param ProductGroup $product_group
     *
     * @return bool
     */
    public function update(UserPolicy $user, ProductGroup $product_group)
    {
        if ($user->canDo('product.product_group.edit') && $user->isAdmin()) {
            return true;
        }

        return $product_group->user_id == user_id() && $product_group->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given product_group.
     *
     * @param UserPolicy $user
     * @param ProductGroup $product_group
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ProductGroup $product_group)
    {
        return $product_group->user_id == user_id() && $product_group->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given product_group.
     *
     * @param UserPolicy $user
     * @param ProductGroup $product_group
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ProductGroup $product_group)
    {
        if ($user->canDo('product.product_group.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given product_group.
     *
     * @param UserPolicy $user
     * @param ProductGroup $product_group
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ProductGroup $product_group)
    {
        if ($user->canDo('product.product_group.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
